@@ -10,6 +10,14 @@
 @CREATED    : June 13, 1994 (Peter Neelin)
 @MODIFIED   : 
  * $Log: worldtovoxel.c,v $
+ * Revision 6.8  2008/01/17 02:33:02  rotor
+ *  * removed all rcsids
+ *  * removed a bunch of ^L's that somehow crept in
+ *  * removed old (and outdated) BUGS file
+ *
+ * Revision 6.7  2008/01/12 19:08:15  stever
+ * Add __attribute__ ((unused)) to all rcsid variables.
+ *
  * Revision 6.6  2006/05/19 00:35:58  bert
  * Add config.h to several files that might need it
  *
@@ -67,10 +75,6 @@
               express or implied warranty.
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/coordinates/worldtovoxel.c,v 6.6 2006/05/19 00:35:58 bert Exp $";
-#endif
-
 #if HAVE_CONFIG_H
 #include "config.h"
 #endif
