@@ -10,6 +10,21 @@
 @CREATED    : May 19, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincinfo.c,v $
+ * Revision 6.12  2008/01/17 02:33:02  rotor
+ *  * removed all rcsids
+ *  * removed a bunch of ^L's that somehow crept in
+ *  * removed old (and outdated) BUGS file
+ *
+ * Revision 6.11  2008/01/13 04:30:28  stever
+ * Add braces around static initializers.
+ *
+ * Revision 6.10  2008/01/12 19:08:15  stever
+ * Add __attribute__ ((unused)) to all rcsid variables.
+ *
+ * Revision 6.9  2007/12/11 12:43:01  rotor
+ *  * added static to all global variables in main programs to avoid linking
+ *       problems with libraries (compress in mincconvert and libz for example)
+ *
  * Revision 6.8  2006/07/28 18:20:53  baghdadi
  * *** empty log message ***
  *
@@ -91,10 +106,6 @@
               express or implied warranty.
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincinfo/mincinfo.c,v 6.8 2006/07/28 18:20:53 baghdadi Exp $";
-#endif
-
 #if HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -115,9 +126,9 @@ static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincinfo/mincinfo.c,v
 #define MAX_NUM_OPTIONS 100
 
 /* Name of program, for error reporting */
-char* exec_name;
+static char* exec_name;
 
-char *type_names[] = {
+static char *type_names[] = {
    NULL, "byte", "char", "short", "long", "float", "double"
 };
 
@@ -145,9 +156,9 @@ static int report_error(void);
 static int get_attname(int mincid, char *string, int *varid, char *name);
 static int print_image_info(char *filename, int mincid);
 /* Variables used for argument parsing */
-char *error_string = NULL;
-Option_type option_list[MAX_NUM_OPTIONS] = {ENDLIST};
-int length_option_list = 0;
+static char *error_string = NULL;
+static Option_type option_list[MAX_NUM_OPTIONS] = { { ENDLIST, "" } };
+static int length_option_list = 0;
 
 /* Argument table */
 ArgvInfo argTable[] = {
