@@ -14,10 +14,6 @@
 
 #include  <internal_volume_io.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Prog_utils/progress.c,v 1.10 2004/10/04 20:23:52 bert Exp $";
-#endif
-
 #define  FIRST_MESSAGE_THRESHOLD   5.0
 
 #define  ONE_LINE_THRESHOLD        160.0
